Visual Studio Team Services Continuous Delivery Manager
=======================================================

This project provides the class ContinuousDeliveryManager and supporting classes. This CD manager class allows
the caller to manage Azure Continuous Delivery pipelines that are maintained within a VSTS account.

Contribute Code
===============

This project has adopted the [Microsoft Open Source Code of Conduct](https://opensource.microsoft.com/codeofconduct/). For more information see the [Code of Conduct FAQ](https://opensource.microsoft.com/codeofconduct/faq/) or contact [opencode@microsoft.com](mailto:opencode@microsoft.com) with any additional questions or comments.
